@@ -3,7 +3,6 @@
 from .download_xiuxian_data import download_xiuxian_data
 from nonebot.plugin import PluginMetadata
 from nonebot import load_all_plugins
-from nonebot import get_bot
 from nonebot.log import logger
 from nonebot.message import event_preprocessor, IgnoredException
 from nonebot.adapters.onebot.v11 import (
@@ -17,18 +16,24 @@ DRIVER = get_driver()
 
 try:
     NICKNAME: str = list(DRIVER.config.nickname)[0]
-except KeyError:
+except Exception as e:
+    logger.info(f"缺少超级用户配置文件，{e}!")
     NICKNAME = 'bot'
 
 try:
     download_xiuxian_data()
 except Exception as e:
-    logger.info(f"缺少配置文件，修仙插件无法加载，{e}！")
+    logger.info(f"下载配置文件失败，修仙插件无法加载，{e}!")
     raise ImportError
 
 put_bot = XiuConfig().put_bot
 shield_group = XiuConfig().shield_group
 
+try:
+    put_bot_ = put_bot[0]
+except:
+    logger.info(f"修仙插件没有配置put_bot,如果有多个qq和nb链接,请务必配置put_bot,具体介绍参考【风控帮助】！")
+
 src = ''
 load_all_plugins(
     [
@@ -62,23 +67,18 @@ __plugin_meta__ = PluginMetadata(
 )
 
 
-@DRIVER.on_startup
-async def put_bot_():
-    global put_bot
-    if put_bot is []:
-        put_bot = put_bot.append(str(get_bot().self_id))
-        logger.info(f"修仙插件没有配置put_bot，已自动配置{put_bot}")
-
-
 @event_preprocessor
 async def do_something(bot: Bot, event: GroupMessageEvent):
+    global put_bot
     if not put_bot:
         pass
     else:
         if str(bot.self_id) in put_bot:
             if str(event.group_id) in shield_group:
-                raise IgnoredException("为屏蔽群消息，已忽略")
+                raise IgnoredException("为屏蔽群消息,已忽略")
             else:
                 pass
         else:
-            raise IgnoredException("非主bot信息，已忽略")
+            raise IgnoredException("非主bot信息,已忽略")
+
+
