@@ -1,4 +1,5 @@
 import asyncio
+import re
 import random
 from datetime import datetime
 from nonebot import on_command, require, get_bots, on_fullmatch
@@ -12,7 +13,7 @@ from nonebot.adapters.onebot.v11 import (
     GROUP_OWNER,
     ActionFailed
 )
-from ..lay_out import assign_bot, put_bot, Cooldown, CooldownIsolateLevel
+from ..lay_out import assign_bot, assign_bot_group, Cooldown, CooldownIsolateLevel
 from nonebot.log import logger
 from nonebot.params import CommandArg
 from nonebot.permission import SUPERUSER
@@ -56,6 +57,7 @@ shop = on_command("坊市查看", aliases={'查看坊市'}, priority=8, permissi
 shop_added = on_command("坊市上架", priority=10, permission=GROUP, block=True)
 shop_added_by_admin = on_command("系统坊市上架", priority=5, permission=SUPERUSER, block=True)
 shop_off = on_command("坊市下架", priority=5, permission=GROUP, block=True)
+shop_off_all = on_fullmatch("清空坊市", priority=3, permission=SUPERUSER, block=True)
 mind_back = on_command('我的背包', aliases={'我的物品'}, priority=10, permission=GROUP, block=True)
 use = on_command("使用", priority=15, permission=GROUP, block=True)
 no_use_zb = on_command("换装", priority=5, permission=GROUP, block=True)
@@ -70,21 +72,22 @@ chakan_wupin = on_command("查看修仙界物品", priority=25, permission=GROUP
 __back_help__ = f"""
 背包帮助信息:
 指令：
-1、我的背包、我的物品：查看自身背包信息
-2、使用+物品名字：使用物品
+1、我的背包、我的物品:查看自身背包前98个物品的信息
+2、使用+物品名字：使用物品,丹药可批量使用
 3、换装+装备名字：卸载目标装备
-4、坊市购买+物品编号：购买坊市内的物品
-5、坊市查看、查看坊市：查询坊市在售物品
-6、坊市上架：坊市上架 物品 金额，上架背包内的物品
-7、系统坊市上架：系统坊市上架 物品 金额，上架任意存在的物品，超管权限
+4、坊市购买+物品编号:购买坊市内的物品
+5、坊市查看、查看坊市:查询坊市在售物品
+6、坊市上架:坊市上架 物品 金额，上架背包内的物品,最低金额50w
+7、系统坊市上架:系统坊市上架 物品 金额，上架任意存在的物品，超管权限
 8、坊市下架+物品编号：下架坊市内的物品，管理员和群主可以下架任意编号的物品！
-9、群交流会开启、关闭：开启交友行功能，管理员指令，注意：会在机器人所在的全部已开启此功能的群内通报交友消息
+9、群交流会开启、关闭:开启交友行功能，管理员指令，注意：会在机器人所在的全部已开启此功能的群内通报交友消息
 10、交友+金额：对本次交友会的物品进行交友
-11、炼金+物品名字：将物品炼化为灵石
-12、背包帮助：获取背包帮助指令
-13、查看修仙界物品：支持类型【功法|神通|丹药|合成丹药|法器|防具】
+11、炼金+物品名字：将物品炼化为灵石,支持批量炼金和绑定丹药炼金
+12、背包帮助:获取背包帮助指令
+13、查看修仙界物品:支持类型【功法|神通|丹药|合成丹药|法器|防具】
+14、清空坊市:清空本群坊市,管理员权限
 非指令：
-1、定时生成交友会，每天{auction_time_config['hours']}点每整点生成一场交友会
+1、定时生成交友会,每天{auction_time_config['hours']}点每整点生成一场交友会
 """.strip()
 
 
@@ -98,7 +101,6 @@ async def reset_day_num_scheduler_():
 # 定时任务生成交友会
 @set_auction_by_scheduler.scheduled_job("cron", hour=auction_time_config['hours'])
 async def set_auction_by_scheduler_():
-    bot = get_bots()[put_bot[0]]
     if groups:
         global auction
         if auction != {}:  # 存在交友会
@@ -117,7 +119,7 @@ async def set_auction_by_scheduler_():
         msg += get_auction_msg(auction_id)
         msg += f"\n底价为{start_price}灵石"
         msg += "\n请诸位道友发送 交友+金额 来进行交友吧！"
-        msg += f"\n本次竞拍时间为：{AUCTIONSLEEPTIME}秒！"
+        msg += f"\n本次竞拍时间为:{AUCTIONSLEEPTIME}秒！"
         auction['id'] = auction_id
         auction['user_id'] = 0
         auction['now_price'] = start_price
@@ -126,6 +128,7 @@ async def set_auction_by_scheduler_():
         auction['start_time'] = datetime.now()
         auction['group_id'] = 0
         for group_id in groups:
+            bot = await assign_bot_group(group_id=group_id)
             try:
                 if XiuConfig().img:
                     pic = await get_msg_pic(msg)
@@ -154,6 +157,7 @@ async def set_auction_by_scheduler_():
             msg = "很可惜，本次交友会流拍了！"
             auction = {}
             for group_id in groups:
+                bot = await assign_bot_group(group_id=group_id)
                 try:
                     if XiuConfig().img:
                         pic = await get_msg_pic(msg)
@@ -167,8 +171,9 @@ async def set_auction_by_scheduler_():
         user_info = sql_message.get_user_message(auction['user_id'])
         user_stone = user_info.stone
         if user_stone < now_price:
-            msg = f"交友会结算！竞拍者灵石小于交友，判定为捣乱，捣乱次数+1！"
+            msg = f"交友会结算！竞拍者灵石小于交友，判定为捣乱，捣乱次数+1!"
             for group_id in groups:
+                bot = await assign_bot_group(group_id=group_id)
                 try:
                     if XiuConfig().img:
                         pic = await get_msg_pic(msg)
@@ -179,8 +184,9 @@ async def set_auction_by_scheduler_():
                     continue
             return
         msg = "本次交友会结束！"
-        msg += f"恭喜来自群{auction['group_id']}的{user_info.user_name}道友成功交友获得：{auction['type']}-{auction['name']}！"
+        msg += f"恭喜来自群{auction['group_id']}的{user_info.user_name}道友成功交友获得：{auction['type']}-{auction['name']}!"
         for group_id in groups:
+            bot = await assign_bot_group(group_id=group_id)
             try:
                 if XiuConfig().img:
                     pic = await get_msg_pic(msg)
@@ -238,7 +244,7 @@ async def xiuxian_sone_(bot: Bot, event: GroupMessageEvent):
 buy_lock = asyncio.Lock()
 
 
-@buy.handle(parameterless=[Cooldown(0.3, isolate_level=CooldownIsolateLevel.GROUP)])
+@buy.handle(parameterless=[Cooldown(1.4, isolate_level=CooldownIsolateLevel.GROUP)])
 async def buy_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg()):
     """购物"""
     bot, send_group_id = await assign_bot(bot=bot, event=event)
@@ -303,28 +309,18 @@ async def buy_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg())
             sql_message.update_ls(user_id, goods_price, 2)
             shop_user_id = shop_data[group_id][str(arg)]['user_id']
             shop_goods_name = shop_data[group_id][str(arg)]['goods_name']
-            shop_user_name = shop_data[group_id][str(arg)]['goods_name']
+            shop_user_name = shop_data[group_id][str(arg)]['user_name']
             shop_goods_id = shop_data[group_id][str(arg)]['goods_id']
             shop_goods_type = shop_data[group_id][str(arg)]['goods_type']
             sql_message.send_back(user_id, shop_goods_id, shop_goods_name, shop_goods_type, 1)
             if shop_user_id == 0:  # 0为系统
                 msg = f"道友成功购买物品{shop_goods_name}，消耗灵石{goods_price}枚！"
             else:
-                msg = f"道友成功购买{shop_user_name}道友寄售的物品{shop_goods_name}，消耗灵石{goods_price}枚！"
-                service_charge = int(goods_price * 0.05)  # 手续费5%
+                service_charge = int(goods_price * 0.1)  # 手续费10%
                 give_stone = goods_price - service_charge
-                shop_msg1 = f"道友上架的{shop_goods_name}已被购买，获得灵石{give_stone}枚，坊市收取手续费：{service_charge}枚灵石！"
-                shop_msg2 = Message(f"[CQ:at,qq={shop_user_id}]")
+                msg = f"道友成功购买{shop_user_name}道友寄售的物品{shop_goods_name}，消耗灵石{goods_price}枚,坊市收取手续费：{service_charge}枚灵石！"
                 sql_message.update_ls(shop_user_id, give_stone, 1)
-                del shop_data[group_id][str(arg)]
-                try:
-                    if XiuConfig().img:
-                        pic = await get_msg_pic(shop_msg1)
-                        await bot.send(event=event, message=MessageSegment.image(pic) + shop_msg2)
-                    else:
-                        await bot.send(event=event, message=Message(shop_msg1) + shop_msg2)
-                except ActionFailed:
-                    pass
+                del shop_data[group_id][str(arg)]    
             shop_data[group_id] = reset_dict_num(shop_data[group_id])
             save_shop(shop_data)
             if XiuConfig().img:
@@ -374,7 +370,7 @@ async def shop_(bot: Bot, event: GroupMessageEvent):
     await shop.finish()
 
 
-@shop_added_by_admin.handle(parameterless=[Cooldown(0.3, isolate_level=CooldownIsolateLevel.GROUP)])
+@shop_added_by_admin.handle(parameterless=[Cooldown(1.4, isolate_level=CooldownIsolateLevel.GROUP, parallel=1)])
 async def shop_added_by_admin_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg()):
     """上架坊市"""
     bot, send_group_id = await assign_bot(bot=bot, event=event)
@@ -470,7 +466,7 @@ async def shop_added_by_admin_(bot: Bot, event: GroupMessageEvent, args: Message
     await shop_added_by_admin.finish()
 
 
-@shop_added.handle(parameterless=[Cooldown(0.3, isolate_level=CooldownIsolateLevel.GROUP)])
+@shop_added.handle(parameterless=[Cooldown(1.4, isolate_level=CooldownIsolateLevel.GROUP)])
 async def shop_added_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg()):
     """上架坊市"""
     bot, send_group_id = await assign_bot(bot=bot, event=event)
@@ -567,7 +563,8 @@ async def shop_added_(bot: Bot, event: GroupMessageEvent, args: Message = Comman
         await shop_added.finish()
     except LookupError:
         pass
-
+    if price <500000:
+        price = 500000    
     if goods_type == "装备" and int(goods_state) == 1 and int(goods_num) == 1:
         msg = f"装备：{goods_name}已经被道友装备在身，无法上架！"
         if XiuConfig().img:
@@ -585,9 +582,36 @@ async def shop_added_(bot: Bot, event: GroupMessageEvent, args: Message = Comman
         else:
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
         await shop_added.finish()
+    if goods_type == "聚灵旗" or goods_type == "炼丹炉":
+        if user_info.root == "器师" :
+            pass
+        else:
+            msg = f"道友职业无法上架！"
+            if XiuConfig().img:
+                pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
+                await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
+            else:
+                await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+            await shop_added.finish() 
 
     group_id = str(event.group_id)
     shop_data = get_shop_data(group_id)
+
+    num = 0
+    for k, v in shop_data[group_id].items():
+        if str(v['user_id']) == str(user_info.user_id):
+            num += 1
+        else:
+            pass
+    if num >= 5 :
+        msg = f"每人只可上架两个物品！"
+        if XiuConfig().img:
+            pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
+            await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
+        else:
+            await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+        await shop_added.finish()
+
     if shop_data == {}:
         shop_data[group_id] = {}
     id_ = len(shop_data[group_id]) + 1
@@ -647,7 +671,6 @@ async def goods_re_root_(bot: Bot, event: GroupMessageEvent, args: Message = Com
     goods_type = None
     goods_state = None
     goods_num = None
-    goods_bind_num = None
     for back in back_msg:
         if goods_name == back.goods_name:
             in_flag = True
@@ -655,7 +678,6 @@ async def goods_re_root_(bot: Bot, event: GroupMessageEvent, args: Message = Com
             goods_type = back.goods_type
             goods_state = back.state
             goods_num = back.goods_num
-            goods_bind_num = back.bind_num
             break
     if not in_flag:
         msg = f"请检查该道具 {goods_name} 是否在背包内！"
@@ -675,14 +697,6 @@ async def goods_re_root_(bot: Bot, event: GroupMessageEvent, args: Message = Com
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
         await goods_re_root.finish()
 
-    if goods_type == "丹药" and int(goods_num) <= int(goods_bind_num):
-        msg = f"该物品是绑定物品，无法炼金！"
-        if XiuConfig().img:
-            pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
-            await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
-        else:
-            await bot.send_group_msg(group_id=int(send_group_id), message=msg)
-        await goods_re_root.finish()
     if get_item_msg_rank(goods_id) == 520:
         msg = "此类物品不支持！"
         if XiuConfig().img:
@@ -691,9 +705,12 @@ async def goods_re_root_(bot: Bot, event: GroupMessageEvent, args: Message = Com
         else:
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
         await goods_re_root.finish()
-    price = int(6000000 - get_item_msg_rank(goods_id) * 100000)
-    sql_message.update_back_j(user_id, goods_id)
-
+    try:
+        if 1 <= int(args[1]) <= int(goods_num):
+            num = int(args[1])
+    except:
+            num = 1 
+    price = int(6000000 - get_item_msg_rank(goods_id) * 100000) * num
     if price <= 0:
         msg = f"物品：{goods_name}炼金失败，凝聚{price}枚灵石，记得通知晓楠！"
         if XiuConfig().img:
@@ -703,8 +720,9 @@ async def goods_re_root_(bot: Bot, event: GroupMessageEvent, args: Message = Com
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
         await goods_re_root.finish()
 
+    sql_message.update_back_j(user_id, goods_id, num=num)
     sql_message.update_ls(user_id, price, 1)
-    msg = f"物品：{goods_name}炼金成功，凝聚{price}枚灵石！"
+    msg = f"物品：{goods_name} 数量：{num} 炼金成功，凝聚{price}枚灵石！"
     if XiuConfig().img:
         pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
         await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
@@ -713,7 +731,7 @@ async def goods_re_root_(bot: Bot, event: GroupMessageEvent, args: Message = Com
     await goods_re_root.finish()
 
 
-@shop_off.handle(parameterless=[Cooldown(0.3, isolate_level=CooldownIsolateLevel.GROUP)])
+@shop_off.handle(parameterless=[Cooldown(1.4, isolate_level=CooldownIsolateLevel.GROUP, parallel=1)])
 async def shop_off_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg()):
     """下架商品"""
     bot, send_group_id = await assign_bot(bot=bot, event=event)
@@ -790,16 +808,15 @@ async def shop_off_(bot: Bot, event: GroupMessageEvent, args: Message = CommandA
                                   shop_data[group_id][str(arg)]['goods_type'], 1)
             msg = f"成功下架{shop_data[group_id][str(arg)]['user_id']}的物品：{shop_data[group_id][str(arg)]['goods_name']}！"
             msg1 = f"道友上架的{shop_data[group_id][str(arg)]['goods_name']}已被管理员{user_id}下架！"
-            msg2 = Message(f"[CQ:at,qq={shop_data[group_id][str(arg)]['user_id']}]")
             del shop_data[group_id][str(arg)]
             shop_data[group_id] = reset_dict_num(shop_data[group_id])
             save_shop(shop_data)
             try:
                 if XiuConfig().img:
                     pic = await get_msg_pic(msg1)
-                    await bot.send(event=event, message=MessageSegment.image(pic) + msg2)
+                    await bot.send(event=event, message=MessageSegment.image(pic))
                 else:
-                    await bot.send(event=event, message=Message(msg1) + msg2)
+                    await bot.send(event=event, message=Message(msg1))
             except ActionFailed:
                 pass
 
@@ -836,6 +853,8 @@ async def mind_back_(bot: Bot, event: GroupMessageEvent):
         await mind_back.finish()
     user_id = user_info.user_id
     msg = get_user_back_msg(user_id)
+    if len(msg) >= 98:
+        msg = msg[:98]
     if msg:
         msg = [f"{user_info.user_name}的背包，持有灵石：{user_info.stone}枚"] + msg
         try:
@@ -947,8 +966,8 @@ async def use_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg())
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
         await use.finish()
     user_id = user_info.user_id
-    arg = args.extract_plain_text().strip()
-
+    args = args.extract_plain_text().split()
+    arg = args[0]  # 
     back_msg = sql_message.get_back_msg(user_id)  # 背包sql信息,list(back)
     if back_msg is None:
         msg = "道友的背包空空如也！"
@@ -961,11 +980,13 @@ async def use_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg())
     in_flag = False  # 判断指令是否正确，道具是否在背包内
     goods_id = None
     goods_type = None
+    goods_num = None
     for back in back_msg:
         if arg == back.goods_name:
             in_flag = True
             goods_id = back.goods_id
             goods_type = back.goods_type
+            goods_num = back.goods_num
             break
     if not in_flag:
         msg = f"请检查该道具 {arg} 是否在背包内！"
@@ -1028,7 +1049,13 @@ async def use_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg())
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
         await use.finish()
     elif goods_type == "丹药":
-        msg = check_use_elixir(user_id, goods_id)
+        num = None
+        try:
+            if 1 <= int(args[1]) <= int(goods_num):
+                num = int(args[1])
+        except:
+            num = 1
+        msg = check_use_elixir(user_id, goods_id, num)
         if XiuConfig().img:
             pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
             await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
@@ -1056,9 +1083,8 @@ async def use_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg())
 
 @creat_auction.handle(parameterless=[Cooldown(at_sender=True)])
 async def creat_auction_(bot: Bot, event: GroupMessageEvent):
-    bot = get_bots()[put_bot[0]]
     group_id = str(event.group_id)
-
+    bot = await assign_bot_group(group_id=group_id)
     if group_id not in groups:
         msg = '本群尚未开启交友会功能，请联系管理员开启！'
         if XiuConfig().img:
@@ -1096,7 +1122,7 @@ async def creat_auction_(bot: Bot, event: GroupMessageEvent):
     msg += get_auction_msg(auction_id)
     msg += f"\n底价为{start_price}灵石"
     msg += "\n请诸位道友发送 交友+金额 来进行交友吧！"
-    msg += f"\n本次竞拍时间为：{AUCTIONSLEEPTIME}秒！"
+    msg += f"\n本次竞拍时间为:{AUCTIONSLEEPTIME}秒！"
 
     auction['id'] = auction_id
     auction['user_id'] = 0
@@ -1107,6 +1133,7 @@ async def creat_auction_(bot: Bot, event: GroupMessageEvent):
     auction['group_id'] = group_id
 
     for group_id in groups:
+        bot = await assign_bot_group(group_id=group_id)
         try:
             if XiuConfig().img:
                 pic = await get_msg_pic(msg)
@@ -1133,6 +1160,7 @@ async def creat_auction_(bot: Bot, event: GroupMessageEvent):
         msg = "很可惜，本次交友会流拍了！"
         auction = {}
         for group_id in groups:
+            bot = await assign_bot_group(group_id=group_id)
             try:
                 if XiuConfig().img:
                     pic = await get_msg_pic(msg)
@@ -1147,7 +1175,7 @@ async def creat_auction_(bot: Bot, event: GroupMessageEvent):
     now_price = int(auction['now_price'])
     user_stone = user_info.stone
     if user_stone < now_price:
-        msg = f"交友会结算！竞拍者灵石小于交友，判定为捣乱，捣乱次数+1！"
+        msg = f"交友会结算！竞拍者灵石小于交友，判定为捣乱，捣乱次数+1!"
         if XiuConfig().img:
             pic = await get_msg_pic(msg)
             await bot.send_group_msg(group_id=int(group_id), message=MessageSegment.image(pic))
@@ -1156,8 +1184,9 @@ async def creat_auction_(bot: Bot, event: GroupMessageEvent):
         await creat_auction.finish()
 
     msg = "本次交友会结束！"
-    msg += f"恭喜来自群{auction['group_id']}的{user_info.user_name}道友成功交友获得：{auction['type']}-{auction['name']}！"
+    msg += f"恭喜来自群{auction['group_id']}的{user_info.user_name}道友成功交友获得：{auction['type']}-{auction['name']}!"
     for group_id in groups:
+        bot = await assign_bot_group(group_id=group_id)
         try:
             if XiuConfig().img:
                 pic = await get_msg_pic(msg)
@@ -1174,10 +1203,10 @@ async def creat_auction_(bot: Bot, event: GroupMessageEvent):
     await creat_auction.finish()
 
 
-@offer_auction.handle(parameterless=[Cooldown(0.3, isolate_level=CooldownIsolateLevel.GLOBAL)])
+@offer_auction.handle(parameterless=[Cooldown(1.4, isolate_level=CooldownIsolateLevel.GLOBAL)])
 async def offer_auction_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg()):
-    bot = get_bots()[put_bot[0]]
     group_id = str(event.group_id)
+    bot = await assign_bot_group(group_id=group_id)
     if group_id not in groups:
         msg = '本群尚未开启交友会功能，请联系管理员开启！'
         if XiuConfig().img:
@@ -1229,7 +1258,7 @@ async def offer_auction_(bot: Bot, event: GroupMessageEvent, args: Message = Com
             await bot.send_group_msg(group_id=int(group_id), message=msg)
         await creat_auction.finish()
     if price - now_price < min_price:
-        msg = f"交友不得少于当前竞拍价的5%，目前最少加价为：{min_price}灵石，目前竞拍价为：{now_price}！"
+        msg = f"交友不得少于当前竞拍价的5%，目前最少加价为：{min_price}灵石，目前竞拍价为：{now_price}!"
         if XiuConfig().img:
             pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
             await bot.send_group_msg(group_id=int(group_id), message=MessageSegment.image(pic))
@@ -1252,6 +1281,7 @@ async def offer_auction_(bot: Bot, event: GroupMessageEvent, args: Message = Com
     )
     error_msg = None
     for group_id in groups:
+        bot = await assign_bot_group(group_id=group_id)
         try:
             if XiuConfig().img:
                 pic = await get_msg_pic(msg)
@@ -1415,6 +1445,68 @@ async def chakan_wupin_(bot: Bot, event: GroupMessageEvent, args: Message = Comm
         await chakan_wupin.finish()
 
 
+@shop_off_all.handle(parameterless=[Cooldown(60, isolate_level=CooldownIsolateLevel.GROUP, parallel=1)])
+async def shop_off_all_(bot: Bot, event: GroupMessageEvent):
+    """坊市清空"""
+    bot, send_group_id = await assign_bot(bot=bot, event=event)
+    isUser, user_info, msg = check_user(event)
+    if not isUser:
+        if XiuConfig().img:
+            pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
+            await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
+        else:
+            await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+        await shop_off_all.finish()
+    group_id = str(event.group_id)
+    shop_data = get_shop_data(group_id)
+    if shop_data[group_id] == {}:
+        msg = "坊市目前空空如也！"
+        if XiuConfig().img:
+            pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
+            await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
+        else:
+            await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+        await shop_off_all.finish()
+
+    msg = "正在清空,稍等！"
+    if XiuConfig().img:
+        pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
+        await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
+    else:
+        await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+
+    list_msg = []
+    msg = ""
+    num = len(shop_data[group_id])
+    for x in range(num):
+        x = num - x
+        if shop_data[group_id][str(x)]['user_id'] == 0:  # 这么写为了防止bot.send发送失败，不结算
+            msg += f"成功下架物品：{shop_data[group_id][str(x)]['goods_name']}!\n"
+            del shop_data[group_id][str(x)]
+            save_shop(shop_data)
+        else:
+            sql_message.send_back(shop_data[group_id][str(x)]['user_id'], shop_data[group_id][str(x)]['goods_id'],
+                                  shop_data[group_id][str(x)]['goods_name'],
+                                  shop_data[group_id][str(x)]['goods_type'], 1)
+            msg += f"成功下架{shop_data[group_id][str(x)]['user_id']}的物品：{shop_data[group_id][str(x)]['goods_name']}!\n"
+            del shop_data[group_id][str(x)]
+            save_shop(shop_data)
+    shop_data[group_id] = reset_dict_num(shop_data[group_id])
+    save_shop(shop_data)
+    list_msg.append(
+                    {"type": "node", "data": {"name": f"执行清空坊市ing", "uin": bot.self_id,
+                                              "content": msg}})
+    try:
+        await send_forward_msg_list(bot, event, list_msg)
+    except ActionFailed:
+        if XiuConfig().img:
+            pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
+            await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
+        else:
+            await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+    await shop_off_all.finish()
+
+
 def reset_dict_num(dict_):
     i = 1
     temp_dict = {}
@@ -1459,7 +1551,7 @@ def get_auction_msg(auction_id):
 
     if _type == "技能":
         if item_info['item_type'] == '神通':
-            msg = f"{item_info['level']}神通-{item_info['name']}："
+            msg = f"{item_info['level']}神通-{item_info['name']}:"
             msg += get_sec_msg(item_info)
         if item_info['item_type'] == '功法':
             msg = f"{item_info['level']}功法-"
