@@ -23,7 +23,7 @@ from ..xiuxian2_handle import XiuxianDateManage, XiuxianJsonDate, OtherSet
 from ..xiuxian_config import XiuConfig, JsonConfig
 from ..utils import (
     check_user, send_forward_msg,
-    get_msg_pic,
+    get_msg_pic, number_to,
     CommandObjectID
 )
 from ..item_json import Items
@@ -32,6 +32,7 @@ from ..xn_xiuxian_impart import XIUXIAN_IMPART_BUFF, leave_harm_time
 # 定时任务
 scheduler = require("nonebot_plugin_apscheduler").scheduler
 cache_help = {}
+cache_help_fk = {}
 sql_message = XiuxianDateManage()  # sql类
 xiuxian_impart = XIUXIAN_IMPART_BUFF()
 
@@ -53,40 +54,58 @@ rob_stone = on_command("抢劫", aliases={"抢灵石"}, priority=5, permission=G
 restate = on_command("重置状态", permission=SUPERUSER, priority=12, block=True)
 open_xiuxian = on_command("启用修仙功能", aliases={'禁用修仙功能'}, permission=SUPERUSER, priority=5, block=True)
 user_leveluprate = on_command('我的突破概率', aliases={'突破概率'}, priority=5, permission=GROUP, block=True)
+xiuxian_updata_level = on_fullmatch('修仙适配', priority=15, permission=GROUP, block=True)
+xiuxian_uodata_data = on_fullmatch('更新记录', priority=15, permission=GROUP, block=True)
 
 __xiuxian_notes__ = f"""
 指令：
-1、我要修仙：进入修仙模式
-2、我的修仙信息：获取修仙数据
-3、修仙签到：获取灵石及修为
-4、重入仙途：重置灵根数据，每次{XiuConfig().remake}灵石
-5、风控帮助：发送"风控帮助"获取
-6、改名xx：修改你的道号
-7、突破：修为足够后，可突破境界（一定几率失败）
-8、闭关、出关、灵石出关、灵石修炼、双修：修炼增加修为，挂机功能
+1、我要修仙:进入修仙模式
+2、我的修仙信息:获取修仙数据
+3、修仙签到:获取灵石及修为
+4、重入仙途:重置灵根数据,每次{XiuConfig().remake}灵石
+5、风控帮助:发送"风控帮助"获取
+6、改名xx:修改你的道号
+7、突破:修为足够后,可突破境界（一定几率失败）
+8、闭关、出关、灵石出关、灵石修炼、双修:修炼增加修为,挂机功能
 9、送灵石100@xxx,偷灵石@xxx,抢灵石@xxx
-10、排行榜：修仙排行榜，灵石排行榜，战力排行榜，宗门排行榜
-11、悬赏令帮助：获取悬赏令帮助信息
-12、我的状态：查看当前HP,我的功法：查看当前技能
-13、宗门系统：发送"宗门帮助"获取
-14、灵庄系统：发送"灵庄帮助"获取
-15、世界BOSS：发送"世界boss帮助"获取
+10、排行榜:修仙排行榜,灵石排行榜,战力排行榜,宗门排行榜
+11、悬赏令帮助:获取悬赏令帮助信息
+12、我的状态:查看当前HP,我的功法：查看当前技能
+13、宗门系统:发送"宗门帮助"获取
+14、灵庄系统:发送"灵庄帮助"获取
+15、世界BOSS:发送"世界boss帮助"获取
 16、功法/灵田：发送“功法帮助/灵田帮助”查看，当前获取途径看“宗门帮助”
 17、背包/交友：发送"背包帮助"获取
-18、秘境系统：发送"秘境帮助"获取
-19、炼丹帮助：炼丹功能
-20、传承系统：发送"传承帮助/虚神界帮助"获取
-21、启用/禁用修仙功能：当前群开启或关闭修仙功能
+18、秘境系统:发送"秘境帮助"获取
+19、炼丹帮助:炼丹功能
+20、传承系统:发送"传承帮助/虚神界帮助"获取
+21、修仙适配:将1的境界适配到2
+22、启用/禁用修仙功能：当前群开启或关闭修仙功能
+23、更新记录:获取插件最新内容
 """.strip()
 
 __warring_help__ = f"""
-配置地址：修仙插件下xiuxian_config.py
-self.put_bot = []  # 接收消息qq,主qq，框架将只处理此qq的消息，
+配置地址:修仙插件下xiuxian_config.py
+self.put_bot = []  # 接收消息qq,主qq,框架将只处理此qq的消息.
 self.main_bo = []  # 负责发送消息的qq
 self.shield_group = []  # 屏蔽的群聊
-self.layout_bot_dict = {{}}  # QQ所负责的群聊{{群 ：bot}}   其中 bot类型 []或str 
+self.layout_bot_dict = {{}}  # QQ所负责的群聊{{群 :bot}}   其中 bot类型 []或str 
 """.strip()
 
+__xiuxian_updata_data__ = f"""
+## 更新2023.3.1 - 2023.3.6
+1.修复已知bug
+2.支持每个群boss刷新时间定制
+3.支持适配修仙1的境界
+3.宗门可以根据qq号踢人,宗门成员查看获得qq号
+4.支持随机存档背景
+5.支持批量使用丹药
+6.支持批量炼金和炼金绑定丹药
+7.修改了世界积分价格,需要删除boss模块下的config.json生效
+8.增加了修仙全局命令调用锁,默认一分钟五次
+9.增加隐藏职业：器师
+器师：指依托于大宗门下的炼器士，其修为一般很低，但不可小觑，因为一般是大修士的转生与亲信，替大修士完成红尘历练。
+""".strip()
 
 # 重置每日签到
 @scheduler.scheduled_job("cron", hour=0, minute=0)
@@ -95,6 +114,14 @@ async def xiuxian_sing_():
     logger.info("每日修仙签到重置成功！")
 
 
+@xiuxian_uodata_data.handle(parameterless=[Cooldown(at_sender=True)])
+async def mix_elixir_help_(bot: Bot, event: GroupMessageEvent):
+    bot, send_group_id = await assign_bot(bot=bot, event=event)
+    msg = __xiuxian_updata_data__
+    await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+    await xiuxian_uodata_data.finish()
+
+
 @run_xiuxian.handle(parameterless=[Cooldown(at_sender=True)])
 async def run_xiuxian_(bot: Bot, event: GroupMessageEvent):
     """加入修仙"""
@@ -135,7 +162,6 @@ async def sign_in_(bot: Bot, event: GroupMessageEvent):
         await sign_in.finish()
     user_id = user_info.user_id
     result = sql_message.get_sign(user_id)
-    sql_message.update_power2(user_id)
     msg = result
     try:
         if XiuConfig().img:
@@ -170,21 +196,21 @@ async def help_in_(bot: Bot, event: GroupMessageEvent, session_id: int = Command
 async def warring_help_(bot: Bot, event: GroupMessageEvent, session_id: int = CommandObjectID()):
     """风控帮助"""
     bot, send_group_id = await assign_bot(bot=bot, event=event)
-    if session_id in cache_help:
-        await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(cache_help[session_id]))
+    if session_id in cache_help_fk:
+        await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(cache_help_fk[session_id]))
         await warring_help.finish()
     else:
         msg = __warring_help__
         if XiuConfig().img:
             pic = await get_msg_pic(msg)
-            cache_help[session_id] = pic
+            cache_help_fk[session_id] = pic
             await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
         else:
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
         await warring_help.finish()
 
 
-@restart.handle(parameterless=[Cooldown(XiuConfig().remake, at_sender=True)])
+@restart.handle(parameterless=[Cooldown(90, at_sender=True)])
 async def restart_(bot: Bot, event: GroupMessageEvent):
     """刷新灵根信息"""
     bot, send_group_id = await assign_bot(bot=bot, event=event)
@@ -198,15 +224,15 @@ async def restart_(bot: Bot, event: GroupMessageEvent):
         await restart.finish()
     user_id = user_info.user_id
     name, root_type = XiuxianJsonDate().linggen_get()
-    result = sql_message.ramaker(name, root_type, user_id)
+    msg = sql_message.ramaker(name, root_type, user_id)
     sql_message.update_power2(user_id)  # 更新战力
-    msg = result
     try:
         if XiuConfig().img:
             pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
             await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
         else:
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+        await restart.finish()    
     except ActionFailed:
         await restart.finish("修仙界网络堵塞，发送失败!", reply_message=True)
 
@@ -222,7 +248,11 @@ async def rank_(bot: Bot, event: GroupMessageEvent):
         message = message[0]
     if message == "排行榜" or message == "修仙排行榜" or message == "境界排行榜":
         p_rank = sql_message.realm_top()
-        msg = p_rank
+        msg = f"✨位面境界排行榜TOP10✨\n"
+        num = 0
+        for i in p_rank:
+            num += 1
+            msg += f"第{num}位 {i[0]} {i[1]},修为{number_to(i[2])}\n"
         if XiuConfig().img:
             pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
             await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
@@ -231,7 +261,11 @@ async def rank_(bot: Bot, event: GroupMessageEvent):
         await rank.finish()
     elif message == "灵石排行榜":
         a_rank = sql_message.stone_top()
-        msg = a_rank
+        msg = f"✨位面灵石排行榜TOP10✨\n"
+        num = 0
+        for i in a_rank:
+            num += 1
+            msg += f"第{num}位  {i[0]}  灵石：{number_to(i[1])}枚\n"
         if XiuConfig().img:
             pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
             await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
@@ -240,7 +274,11 @@ async def rank_(bot: Bot, event: GroupMessageEvent):
         await rank.finish()
     elif message == "战力排行榜":
         c_rank = sql_message.power_top()
-        msg = c_rank
+        msg = f"✨位面战力排行榜TOP10✨\n"
+        num = 0
+        for i in c_rank:
+            num += 1
+            msg += f"第{num}位  {i[0]}  战力：{number_to(i[1])}\n"
         if XiuConfig().img:
             pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
             await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
@@ -248,8 +286,14 @@ async def rank_(bot: Bot, event: GroupMessageEvent):
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
         await rank.finish()
     elif message in ["宗门排行榜", "宗门建设度排行榜"]:
-        s_rank, _ = sql_message.scale_top()
-        msg = s_rank
+        s_rank = sql_message.scale_top()
+        msg = f"✨位面宗门建设排行榜TOP10✨\n"
+        num = 0
+        for i in s_rank:
+            num += 1
+            msg += f"第{num}位  {i[1]}  建设度：{number_to(i[2])}\n"
+            if num == 10:
+                break
         if XiuConfig().img:
             pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
             await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
@@ -627,7 +671,7 @@ async def give_stone_(bot: Bot, event: GroupMessageEvent, args: Message = Comman
             give_user = sql_message.get_user_message(give_qq)
             if give_user:
                 sql_message.update_ls(user_id, give_stone_num, 2)  # 减少用户灵石
-                give_stone_num2 = int(give_stone_num) * 0.03
+                give_stone_num2 = int(give_stone_num) * 0.1
                 num = int(give_stone_num) - int(give_stone_num2)
                 sql_message.update_ls(give_qq, num, 1)  # 增加用户灵石
                 msg = "共赠送{}枚灵石给{}道友！收取手续费{}枚".format(
@@ -661,7 +705,7 @@ async def give_stone_(bot: Bot, event: GroupMessageEvent, args: Message = Comman
                 await give_stone.finish()
             else:
                 sql_message.update_ls(user_id, give_stone_num, 2)  # 减少用户灵石
-                give_stone_num2 = int(give_stone_num) * 0.03
+                give_stone_num2 = int(give_stone_num) * 0.1
                 num = int(give_stone_num) - int(give_stone_num2)
                 sql_message.update_ls(give_message.user_id, num, 1)  # 增加用户灵石
                 msg = "共赠送{}枚灵石给{}道友！收取手续费{}枚".format(
@@ -693,7 +737,7 @@ async def give_stone_(bot: Bot, event: GroupMessageEvent, args: Message = Comman
 
 
 # 偷灵石
-@steal_stone.handle(parameterless=[Cooldown(XiuConfig().tou, at_sender=True)])
+@steal_stone.handle(parameterless=[Cooldown(XiuConfig().tou_cd, at_sender=True)])
 async def steal_stone_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg()):
     bot, send_group_id = await assign_bot(bot=bot, event=event)
     isUser, user_info, msg = check_user(event)
@@ -858,7 +902,7 @@ async def gm_command_(bot: Bot, event: GroupMessageEvent, args: Message = Comman
         await gm_command.finish()
 
 
-@rob_stone.handle(parameterless=[Cooldown(at_sender=True)])
+@rob_stone.handle(parameterless=[Cooldown(cd_time=600 ,at_sender=True)])
 async def rob_stone_(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg()):
     """抢灵石
             player1 = {
@@ -876,6 +920,14 @@ async def rob_stone_(bot: Bot, event: GroupMessageEvent, args: Message = Command
         else:
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
         await give_stone.finish()
+    if user_info.root == "器师":
+        msg = "目前职业无法抢劫！"
+        if XiuConfig().img:
+            pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
+            await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
+        else:
+            await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+        await rob_stone.finish()
     user_id = user_info.user_id
     give_qq = None  # 艾特的时候存到这里
     for arg in args:
@@ -894,6 +946,14 @@ async def rob_stone_(bot: Bot, event: GroupMessageEvent, args: Message = Command
             await rob_stone.finish()
 
         user_2 = sql_message.get_user_message(give_qq)
+        if user_2.root == "器师":
+            msg = "对方职业无法被抢劫！"
+            if XiuConfig().img:
+                pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
+                await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
+            else:
+                await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+            await rob_stone.finish()
         if user_2:
             if user_info.hp is None:
                 # 判断用户气血是否为None
@@ -929,9 +989,9 @@ async def rob_stone_(bot: Bot, event: GroupMessageEvent, args: Message = Command
             player1['攻击'] = user_info.atk
             player1['真元'] = user_info.mp
             player1['会心'] = int(
-                (1 + impart_data_1.impart_know_per if impart_data_1.impart_know_per is not None else 0) * 100)
+                (0.01 + impart_data_1.impart_know_per if impart_data_1 is not None else 0) * 100)
             player1['爆伤'] = int(
-                1.5 + impart_data_1.impart_burst_per if impart_data_1.impart_burst_pe is not None else 0)
+                1.5 + impart_data_1.impart_burst_per if impart_data_1 is not None else 0)
             user_buff_data = UserBuffDate(user_id)
             user_armor_data = user_buff_data.get_user_armor_buff_data()
             if user_armor_data is not None:
@@ -946,17 +1006,17 @@ async def rob_stone_(bot: Bot, event: GroupMessageEvent, args: Message = Command
             player2['气血'] = user_2.hp
             player2['攻击'] = user_2.atk
             player2['真元'] = user_2.mp
-            player1['会心'] = int(
-                (1 + impart_data_2.impart_know_per if impart_data_2.impart_know_per is not None else 0) * 100)
-            player1['爆伤'] = int(
-                1.5 + impart_data_2.impart_burst_per if impart_data_2.impart_burst_pe is not None else 0)
+            player2['会心'] = int(
+                (0.01 + impart_data_2.impart_know_per if impart_data_2 is not None else 0) * 100)
+            player2['爆伤'] = int(
+                1.5 + impart_data_2.impart_burst_per if impart_data_2 is not None else 0)
             user_buff_data = UserBuffDate(user_2.user_id)
             user_armor_data = user_buff_data.get_user_armor_buff_data()
             if user_armor_data is not None:
                 def_buff = int(user_armor_data['def_buff'])
             else:
                 def_buff = 0
-            player1['防御'] = def_buff
+            player2['防御'] = def_buff
 
             result, victor = OtherSet().player_fight(player1, player2)
             await send_forward_msg(bot, event, '决斗场', bot.self_id, result)
@@ -1105,3 +1165,49 @@ async def open_xiuxian_(bot: Bot, event: GroupMessageEvent):
         else:
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
         await open_xiuxian.finish()
+
+
+@xiuxian_updata_level.handle(parameterless=[Cooldown(at_sender=True)])
+async def xiuxian_updata_level_(bot: Bot, event: GroupMessageEvent):
+    """将修仙1的境界适配到修仙2"""
+    bot, send_group_id = await assign_bot(bot=bot, event=event)
+    isUser, user_info, msg = check_user(event)
+    if not isUser:
+        if XiuConfig().img:
+            pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
+            await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
+        else:
+            await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+        await xiuxian_updata_level.finish()
+    level_dict={
+        "练气境":"搬血境",
+        "筑基境":"洞天境",
+        "结丹境":"化灵境",
+        "元婴境":"铭纹境",
+        "化神境":"列阵境",
+        "炼虚境":"尊者境",
+        "合体境":"神火境",
+        "大乘境":"真一境",
+        "渡劫境":"圣祭境",
+        "半步真仙":"天神境中期",
+        "真仙境":"虚道境",
+        "金仙境":"斩我境",
+        "太乙境":"遁一境"
+    }
+    level = user_info.level
+    user_id = user_info.user_id
+    if level == "半步真仙":
+        level = "天神境中期"
+    else:
+        try:
+            level = level_dict.get(level[:3]) + level[-2:]
+        except:
+            level = level
+    sql_message.updata_level(user_id=user_id,level_name=level)
+    msg = '境界适配成功成功！'
+    if XiuConfig().img:
+        pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
+        await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
+    else:
+        await bot.send_group_msg(group_id=int(send_group_id), message=msg)
+    await xiuxian_updata_level.finish()
\ No newline at end of file
