@@ -40,20 +40,20 @@ mix_elixir_dykh_up = on_fullmatch("升级丹药控火", priority=6, permission=G
 __elixir_help__ = f"""
 炼丹帮助信息:
 指令：
-1、炼丹：会检测背包内的药材，自动生成配方【一次最多匹配25种药材】
-2、配方：发送配方领取丹药【配方主药.....】
-2、炼丹帮助：获取本帮助信息
-3、炼丹配方帮助：获取炼丹配方帮助
-4、灵田收取、灵田结算：收取洞天福地里灵田的药材
-5、我的炼丹信息：查询自己的炼丹信息
-6、升级收取等级：每一个等级会增加灵田收取的数量
-7、升级丹药控火：每一个等级会增加炼丹的产出数量
+1、炼丹:会检测背包内的药材,自动生成配方【一次最多匹配25种药材】
+2、配方:发送配方领取丹药【配方主药.....】
+2、炼丹帮助:获取本帮助信息
+3、炼丹配方帮助:获取炼丹配方帮助
+4、灵田收取、灵田结算:收取洞天福地里灵田的药材
+5、我的炼丹信息:查询自己的炼丹信息
+6、升级收取等级:每一个等级会增加灵田收取的数量
+7、升级丹药控火:每一个等级会增加炼丹的产出数量
 """
 
 __mix_elixir_help__ = f"""
 炼丹配方信息
 1、炼丹需要主药、药引、辅药
-2、主药和药引控制炼丹时的冷热调和，冷热失和则炼不出丹药
+2、主药和药引控制炼丹时的冷热调和,冷热失和则炼不出丹药
 3、草药的类型控制产出丹药的类型
 4、来自群友猫猫头工具网址 
 https://huggingface.co/spaces/chewing/liandan
@@ -257,7 +257,7 @@ async def my_mix_elixir_info_(bot: Bot, event: GroupMessageEvent):
         l_msg.append(f"☆------道友的炼丹记录------☆")
         i = 1
         for k, v in mix_elixir_info['炼丹记录'].items():
-            msg = f"编号：{i}，{v['name']}，炼成次数：{v['num']}次"
+            msg = f"编号：{i},{v['name']}，炼成次数：{v['num']}次"
             l_msg.append(msg)
             i += 1
     await send_forward_msg(bot, event, '炼丹信息', bot.self_id, l_msg)
@@ -293,7 +293,7 @@ user_ldl_dict = {}
 user_ldl_flag = {}
 
 
-@mix_elixir.handle(parameterless=[Cooldown(at_sender=True)])
+@mix_elixir.handle(parameterless=[Cooldown(cd_time=10, at_sender=True)])
 async def mix_elixir_(bot: Bot, event: GroupMessageEvent):
     global user_ldl_dict, user_ldl_flag
     bot, send_group_id = await assign_bot(bot=bot, event=event)
@@ -347,12 +347,6 @@ async def mix_elixir_(bot: Bot, event: GroupMessageEvent):
         else:
             await bot.send_group_msg(group_id=int(send_group_id), message=msg)
         await mix_elixir.finish()
-    msg = "正在匹配背包中的丹方，请等待"
-    if XiuConfig().img:
-        pic = await get_msg_pic(f"@{event.sender.nickname}\n" + msg)
-        await bot.send_group_msg(group_id=int(send_group_id), message=MessageSegment.image(pic))
-    else:
-        await bot.send_group_msg(group_id=int(send_group_id), message=msg)
 
     yaocai_dict = await make_dict(yaocai_dict)
     finall_mix_elixir_msg = await get_mix_elixir_msg(yaocai_dict)
@@ -374,10 +368,10 @@ async def mix_elixir_(bot: Bot, event: GroupMessageEvent):
             msg += f"效果：{goods_info['desc']}\n"
             msg += f"配方：{v['配方']['配方简写']}丹炉{ldl_name}\n"
             msg += f"☆------药材清单------☆\n"
-            msg += f"主药：{v['配方']['主药']}，{v['配方']['主药_level']}，数量：{v['配方']['主药_num']}\n"
-            msg += f"药引：{v['配方']['药引']}，{v['配方']['药引_level']}，数量：{v['配方']['药引_num']}\n"
+            msg += f"主药：{v['配方']['主药']},{v['配方']['主药_level']}，数量：{v['配方']['主药_num']}\n"
+            msg += f"药引：{v['配方']['药引']},{v['配方']['药引_level']}，数量：{v['配方']['药引_num']}\n"
             if v['配方']['辅药_num'] != 0:
-                msg += f"辅药：{v['配方']['辅药']}，{v['配方']['辅药_level']}，数量：{v['配方']['辅药_num']}\n"
+                msg += f"辅药：{v['配方']['辅药']},{v['配方']['辅药_level']}，数量：{v['配方']['辅药_num']}\n"
             l_msg.append(msg)
         if len(l_msg) > 51:
             l_msg = l_msg[:50]
@@ -509,7 +503,7 @@ async def _mix_elixir(bot: Bot, event: GroupMessageEvent, mode: str = EventPlain
                         mix_elixir_info['炼丹经验'] += goods_info['mix_exp'] * num
                         msg += f"获得炼丹经验{goods_info['mix_exp'] * num}点"
                     mix_elixir_info['炼丹记录'][id]['num'] += num
-                except (OSError, IOError, LookupError):
+                except:
                     mix_elixir_info['炼丹记录'][id] = {}
                     mix_elixir_info['炼丹记录'][id]['name'] = goods_info['name']
                     mix_elixir_info['炼丹记录'][id]['num'] = num
